@@ -28,11 +28,17 @@ class PlainPlugin(Plugin):
 
     # if not in hard mode, checks if symlink points to file in repo
     # if in hard mode, a bit-by-bit comparison is made to compare the files
-    def samefile(self, file1, file2):
+    def samefile(self, repo_file, ext_file):
         if self.hard:
-            return filecmp.cmp(file1, file2, shallow=False)
+            if os.path.islink(ext_file):
+                return False
+            if not os.path.exists(repo_file):
+                return False
+            return filecmp.cmp(repo_file, ext_file, shallow=False)
         else:
-            return os.path.samefile(file1, file2)
+            # not using os.samefile since it resolves repo_file as well which
+            # is not what we want
+            return os.path.realpath(ext_file) == os.path.abspath(repo_file)
 
     def strify(self, op):
         if op == self.apply:
